@@ -25,7 +25,7 @@ func TestCompressStyle(t *testing.T) {
 func BenchmarkHTMLFormatter(b *testing.B) {
 	formatter := New()
 	b.ResetTimer()
-	for i := 0; i < b.N; i++ {
+	for range b.N {
 		it, err := lexers.Get("go").Tokenise(nil, "package main\nfunc main()\n{\nprintln(`hello world`)\n}\n")
 		assert.NoError(b, err)
 		err = formatter.Format(io.Discard, styles.Fallback, it)
@@ -351,8 +351,7 @@ func TestReconfigureOptions(t *testing.T) {
 }
 
 func TestWriteCssWithAllClasses(t *testing.T) {
-	formatter := New()
-	formatter.allClasses = true
+	formatter := New(WithAllClasses(true))
 
 	var buf bytes.Buffer
 	err := formatter.WriteCSS(&buf, styles.Fallback)
@@ -360,3 +359,17 @@ func TestWriteCssWithAllClasses(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotContains(t, buf.String(), ".chroma . {", "Generated css doesn't contain invalid css")
 }
+
+func TestStyleCache(t *testing.T) {
+	f := New()
+
+	assert.True(t, len(styles.Registry) > styleCacheLimit)
+
+	for _, style := range styles.Registry {
+		var buf bytes.Buffer
+		err := f.WriteCSS(&buf, style)
+		assert.NoError(t, err)
+	}
+
+	assert.Equal(t, styleCacheLimit, len(f.styleCache.cache))
+}
