@@ -2,6 +2,7 @@ package lexers
 
 import (
 	"regexp"
+	"slices"
 	"strings"
 	"unicode/utf8"
 
@@ -655,7 +656,7 @@ func rakuRules() Rules {
 			// Substitution
 			{`(?<=^|\b|\s)(?<!\.)(ss|S|s|TR|tr)\b(\s*)`, ByGroups(Keyword, Text), Push("substitution")},
 			{keywordsPattern, Keyword, nil},
-			{builtinTypesPattern, NameBuiltin, nil},
+			{builtinTypesPattern, KeywordType, nil},
 			{builtinRoutinesPattern, NameBuiltin, nil},
 			// Class name
 			{
@@ -1318,21 +1319,11 @@ func indexAt(str []rune, substr []rune, pos int) int {
 	return idx
 }
 
-// Tells if an array of string contains a string
-func contains(s []string, e string) bool {
-	for _, value := range s {
-		if value == e {
-			return true
-		}
-	}
-	return false
-}
-
 type rulePosition int
 
 const (
-	topRule    rulePosition = 0
-	bottomRule              = -1
+	topRule rulePosition = 0 - iota
+	bottomRule
 )
 
 type ruleMakingConfig struct {
@@ -1625,15 +1616,15 @@ func quote(groups []string, state *LexerState) Iterator {
 	var tokenState string
 
 	switch {
-	case keyword == "qq" || contains(tokenStates, "qq"):
+	case keyword == "qq" || slices.Contains(tokenStates, "qq"):
 		tokenState = "qq"
-	case adverbsStr == "ww" || contains(tokenStates, "ww"):
+	case adverbsStr == "ww" || slices.Contains(tokenStates, "ww"):
 		tokenState = "ww"
-	case contains(tokenStates, "Q-closure") && contains(tokenStates, "Q-variable"):
+	case slices.Contains(tokenStates, "Q-closure") && slices.Contains(tokenStates, "Q-variable"):
 		tokenState = "qq"
-	case contains(tokenStates, "Q-closure"):
+	case slices.Contains(tokenStates, "Q-closure"):
 		tokenState = "Q-closure"
-	case contains(tokenStates, "Q-variable"):
+	case slices.Contains(tokenStates, "Q-variable"):
 		tokenState = "Q-variable"
 	default:
 		tokenState = "Q"
